=====
Usage
=====

This page provides information on how to use `cellmaps_pipeline`_


.. toctree::
   :maxdepth: 2
   :caption: Contents:

   usage_via_command
   usage_programmatically
   provenance
   cm4ai
   hpa_bioplex
   ndex_save


.. _CM4AI data: https://cm4ai.org/data
.. _RO-Crate: https://www.researchobject.org/ro-crate/
.. _Human Protein Atlas: https://www.proteinatlas.org
.. _Bioplex: https://bioplex.hms.harvard.edu
.. _cellmaps_pipeline: https://github.com/idekerlab/cellmaps_pipeline
.. _JSON: https://www.json.org/json-en.html
.. _SLURM: https://slurm.schedmd.com/documentation.html
